StatusCode

Enum StatusCode 

pub enum StatusCode {
    Success,
    NotImplemented,
    InvalidParameter,
    InvalidAddress,
    DeviceBusy,
    Error,
    Unknown(u16),
}
Status codes returned by GenCP acknowledgements.

Variants



Success

Command completed successfully.



NotImplemented

The requested command is not implemented by the device.



InvalidParameter

One of the command parameters was invalid.



InvalidAddress

The requested address range cannot be accessed.



DeviceBusy

The device was busy processing a previous command.



Error

The device reported a generic or transport specific error.



Unknown(u16)

A status code not known to this implementation.

Implementations

Source

impl StatusCode

pub fn from_raw(raw: u16) -> Self

Convert from the raw status field in an acknowledgement header.

pub const fn to_raw(self) -> u16

Convert to the raw value stored in the packet header.